@@ -2,8 +2,8 @@
 # Licensed under the terms of the Apache License, Version 2.0. See the LICENSE file associated with the project for terms.
 """Lightweight :term:`computation` graphs for Python."""
 
-__version__ = "7.1.1"
-__release_date__ = "5 May 2020, 01:30"
+__version__ = "8.0.0"
+__release_date__ = "7 May 2020, 02:15"
 __title__ = "graphtik"
 __summary__ = __doc__.splitlines()[0]
 __license__ = "Apache-2.0"
@@ -11,7 +11,7 @@ __uri__ = "https://github.com/pygraphkit/graphtik"
 __author__ = "hnguyen, ankostis"
 
 
-from .base import NO_RESULT
+from .base import NO_RESULT, AbortedException, IncompleteExecutionError
 from .config import (
     abort_run,
     debug_enabled,
@@ -38,18 +38,18 @@ from .config import (
     tasks_in_parallel,
     tasks_marshalled,
 )
-
-## SEE ALSO: `.plot.active_plotter_plugged()`, `.plot.set_active_plotter()` &
-#  `.plot.get_active_plotter()` configs, not imported, unless plot is needed..
-
 from .modifiers import (
     mapped,
     optional,
+    sfx,
+    sfxed,
+    sfxed_vararg,
+    sfxed_varargs,
     vararg,
     varargs,
-    sideffect,
-    sideffected,
 )
-from .netop import compose
-from .network import AbortedException, IncompleteExecutionError
-from .op import operation, NULL_OP
+from .pipeline import compose
+from .op import NULL_OP, operation
+
+## SEE ALSO: `.plot.active_plotter_plugged()`, `.plot.set_active_plotter()` &
+#  `.plot.get_active_plotter()` configs, not imported, unless plot is needed..
