@@ -1,15 +1,18 @@
 # Copyright 2016, Yahoo Inc.
 # Licensed under the terms of the Apache License, Version 2.0. See the LICENSE file associated with the project for terms.
-"""About :term:`operation` nodes (but not net-ops to break cycle)."""
+"""
+Define :term:`operation` :term:`dependency` & :term:`modifier`\\s, and match/zip inputs/outputs .
+
+... but not net-ops to break the cycle.
+"""
 
 import abc
 import itertools as itt
 import logging
 import textwrap
 from collections import abc as cabc
-from collections import namedtuple
 from functools import wraps
-from typing import Any, Callable, Collection, List, Mapping, Set, Tuple, Union
+from typing import Any, Callable, Collection, List, Mapping, Tuple, Union
 
 from boltons.setutils import IndexedSet as iset
 
@@ -26,31 +29,28 @@ from .base import (
     jetsam,
 )
 from .config import (
+    first_solid,
     is_debug,
     is_endure_operations,
     is_marshal_tasks,
     is_parallel_tasks,
     is_reschedule_operations,
-    first_solid,
 )
 from .modifiers import (
+    dep_singularized,
+    dep_stripped,
     is_mapped,
     is_optional,
-    is_pure_sideffect,
-    is_sideffect,
-    is_sideffected,
+    is_pure_sfx,
+    is_sfx,
+    is_sfxed,
     is_vararg,
     is_varargs,
-    sideffected,
 )
 
 log = logging.getLogger(__name__)
 
 
-def _dict_without(kw, *to_skip):
-    return {k: v for k, v in kw.items() if k not in to_skip}
-
-
 def as_renames(i, argname):
     """
     Parses a list of (source-->destination) from dict, list-of-2-items, single 2-tuple.
@@ -146,49 +146,40 @@ def _spread_sideffects(
 
     :return:
         the given `deps` duplicated as ``(fn_deps,  op_deps)``, where any instances of
-        :func:`.sideffect` and :func:`.sideffected` are processed like this:
+        :term:`sideffects` are processed like this:
 
         `fn_deps`
-            - :func:`.sideffected` are replaced by the pure :attr:`._Modifier.sideffected`
+            - any :func:`.sfxed` are replaced by the :func:`stripped <.dep_stripped>`
               dependency consumed/produced by underlying functions, in the order
-              it is first met (the rest duplicate `sideffected` are discarded).
-            - :func:`.sideffect` are simply dropped;
+              they are first met (the rest duplicate `sideffected` are discarded).
+            - any :func:`.sfx` are simply dropped;
 
         `op_deps`
-            :func:`.sideffected` are replaced by a sequence of "singular" `sideffected`
-            instances, one for each item in their :attr:`._Modifier.sideffects` attribute,
-            in the order they are first met
+            any :func:`.sfxed` are replaced by a sequence of ":func:`singularized
+            <.dep_singularized>`" instances, one for each item in their
+            :attr:`._Modifier.sfx_list` attribute, in the order they are first met
             (any duplicates are discarded, order is irrelevant, since they don't reach
             the function);
     """
 
-    def singularize_sideffecteds(dep):
-        """Make 1 sideffected for each pure-sfx contained, preserving attributes """
-        return (
-            (dep.withset(sideffects=(s,)) for s in dep.sideffects)
-            if is_sideffected(dep)
-            else (dep,)
-        )
-
-    #: The only dupes that are dropped from `fn_deps` are any `sideffected`,
-    #: to facilitate copy-pasting singularized ones from the console.
-    seen_sideffecteds: Set[str] = set()
+    #: The dedupe  any `sideffected`.
+    seen_sideffecteds = set()
 
     def strip_sideffecteds(dep):
-        """Strip the dependency, preserving attributes """
-        if is_sideffected(dep):
-            sideffected = dep.sideffected
-            if not sideffected in seen_sideffecteds:
-                seen_sideffecteds.add(sideffected)
-                return (dep.withset(sideffects=None),)
-        elif not is_sideffect(dep):
+        """Strip and dedupe any sfxed, drop any sfx. """
+        if is_sfxed(dep):
+            dep = dep_stripped(dep)
+            if not dep in seen_sideffecteds:
+                seen_sideffecteds.add(dep)
+                return (dep,)
+        elif not is_sfx(dep):
             return (dep,)
         return ()
 
     assert deps is not None
 
     if deps:
-        deps = tuple(nn for n in deps for nn in singularize_sideffecteds(n))
+        deps = tuple(nn for n in deps for nn in dep_singularized(n))
         fn_deps = tuple(nn for n in deps for nn in strip_sideffecteds(n))
         return deps, fn_deps
     else:
@@ -212,7 +203,6 @@ class FunctionalOperation(Operation, Plottable):
         provides: Items = None,
         aliases: Mapping = None,
         *,
-        parents: Tuple = None,
         rescheduled=None,
         endured=None,
         parallel=None,
@@ -231,10 +221,6 @@ class FunctionalOperation(Operation, Plottable):
 
         if fn and not callable(fn):
             raise TypeError(f"Operation was not provided with a callable: {fn}")
-        if parents and not isinstance(parents, tuple):
-            raise TypeError(
-                f"Operation `parents` must be tuple, was {type(parents).__name__!r}: {parents}"
-            )
         if node_props is not None and not isinstance(node_props, cabc.Mapping):
             raise TypeError(
                 f"Operation `node_props` must be a dict, was {type(node_props).__name__!r}: {node_props}"
@@ -242,8 +228,6 @@ class FunctionalOperation(Operation, Plottable):
 
         if name is None and fn:
             name = func_name(fn, None, mod=0, fqdn=0, human=0, partials=1)
-        if name is not None:
-            name = ".".join(str(pop) for pop in ((parents or ()) + (name,)))
         ## Overwrite reparsed op-data.
         name, needs, provides = reparse_operation_data(name, needs, provides)
 
@@ -268,9 +252,7 @@ class FunctionalOperation(Operation, Plottable):
                     f", not found in provides {list(provides)}!"
                 )
             sfx_aliases = [
-                f"{src} -> {dst}"
-                for src, dst in aliases
-                if is_sideffect(src) or is_sideffect(dst)
+                f"{src} -> {dst}" for src, dst in aliases if is_sfx(src) or is_sfx(dst)
             ]
             if sfx_aliases:
                 raise ValueError(
@@ -284,7 +266,8 @@ class FunctionalOperation(Operation, Plottable):
         #: The :term:`operation`'s underlying function.
         self.fn = fn
         #: a name for the operation (e.g. `'conv1'`, `'sum'`, etc..);
-        #: it will be prefixed by `parents`.
+        #: any "parents split by dots(``.``)".
+        #: :seealso: :ref:`operation-nesting`
         self.name = name
 
         #: The :term:`needs` almost as given by the user
@@ -317,9 +300,6 @@ class FunctionalOperation(Operation, Plottable):
         #:
         #: You cannot alias an :term:`alias`.
         self.aliases = aliases
-        #: a tuple wth the names of the parents, prefixing `name`,
-        #: but also kept for equality/hash check.
-        self.parents = parents
         #: If true, underlying *callable* may produce a subset of `provides`,
         #: and the :term:`plan` must then :term:`reschedule` after the operation
         #: has executed.  In that case, it makes more sense for the *callable*
@@ -350,15 +330,12 @@ class FunctionalOperation(Operation, Plottable):
         self.node_props = node_props
 
     def __eq__(self, other):
-        """Operation identity is based on `name` and `parents`."""
-        return bool(
-            self.name == getattr(other, "name", UNSET)
-            and self.parents == getattr(other, "parents", UNSET)
-        )
+        """Operation identity is based on `name`."""
+        return bool(self.name == getattr(other, "name", UNSET))
 
     def __hash__(self):
-        """Operation identity is based on `name` and `parents`."""
-        return hash(self.name) ^ hash(self.parents)
+        """Operation identity is based on `name`."""
+        return hash(self.name)
 
     def __repr__(self):
         """
@@ -460,10 +437,10 @@ class FunctionalOperation(Operation, Plottable):
         kwargs = {}
         errors, missing, varargs_bad = [], [], []
         for n in self._fn_needs:
-            assert not is_sideffect(n), locals()
+            assert not is_sfx(n), locals()
             try:
                 if n not in named_inputs:
-                    if not is_optional(n) or is_sideffect(n):
+                    if not is_optional(n) or is_sfx(n):
                         # It means `inputs` < compulsory `needs`.
                         # Compilation should have ensured all compulsories existed,
                         # but ..?
@@ -565,7 +542,7 @@ class FunctionalOperation(Operation, Plottable):
 
         elif results == NO_RESULT and rescheduled:
             # Cancel also any SFX.
-            results = {p: False for p in set(self.provides) if is_sideffect(p)}
+            results = {p: False for p in set(self.provides) if is_sfx(p)}
 
         elif not fn_expected:  # All provides were sideffects?
             if results and results != NO_RESULT:
@@ -689,7 +666,7 @@ class FunctionalOperation(Operation, Plottable):
 
     def prepare_plot_args(self, plot_args: PlotArgs) -> PlotArgs:
         """Delegate to a provisional network with a single op . """
-        from .netop import compose
+        from .pipeline import compose
         from .plot import graphviz_html_string
 
         is_user_label = bool(plot_args.graph and plot_args.graph.get("graphviz.label"))
@@ -865,10 +842,14 @@ def operation(
 
 
 class NULL_OP(FunctionalOperation):
-    """Eliminates same-named operations added later during term:`operation merging`."""
+    """
+    Eliminates same-named operations added later during term:`operation merging`.
 
-    def __init__(self, name, parents=None):
-        super().__init__(name=name, parents=parents)
+    :seealso: :ref:`operation-merging`
+    """
+
+    def __init__(self, name):
+        super().__init__(name=name)
 
     def compute(self, *args, **kw):
         raise AssertionError("Should have been eliminated!")
