@@ -1,7 +1,7 @@
 # Copyright 2016, Yahoo Inc.
 # Licensed under the terms of the Apache License, Version 2.0. See the LICENSE file associated with the project for terms.
 """
-Plotting of graph graphs handled by :term:`active plotter` (see also :mod:`.base`).
+:term:`plotting` handled by the :term:`active plotter` & :term:`current theme`.
 
 Separate from `graphtik.base` to avoid too many imports too early.
 
@@ -44,16 +44,14 @@ from boltons.iterutils import default_enter, default_exit, get_path, remap
 
 from .base import PlotArgs, func_name, func_source
 from .config import (
+    first_solid,
     is_debug,
     is_endure_operations,
     is_marshal_tasks,
     is_parallel_tasks,
     is_reschedule_operations,
-    first_solid,
 )
-from .modifiers import is_mapped, is_sideffect, is_sideffected
-from .netop import NetworkOperation
-from .network import ExecutionPlan, Network, Solution, _EvictInstruction
+from .modifiers import is_mapped, is_sfx, is_sfxed
 from .op import Operation
 
 log = logging.getLogger(__name__)
@@ -454,7 +452,7 @@ class Theme:
         "label": make_template(
             """
             <{{ nx_item.sideffected | eee }}<BR/>
-            (<I>sideffect:</I> {{ nx_item.sideffects | join(', ') | eee }})>
+            (<I>sfx:</I> {{ nx_item.sfx_list | join(', ') | eee }})>
             """
         ),
     }
@@ -1002,11 +1000,13 @@ class Plotter:
         return StylesStack(plot_args, [], ignore_errors=ignore_errors)
 
     def plot(self, plot_args: PlotArgs):
+        from .execution import Solution
+
         plot_args = plot_args.with_defaults(
             # Don't leave `solution` unassigned
-            solution=isinstance(plot_args.plottable, Solution)
-            and plot_args.plottable
-            or None,
+            solution=plot_args.plottable
+            if isinstance(plot_args.plottable, Solution)
+            else None,
             theme=self.default_theme,
         )
 
@@ -1114,7 +1114,7 @@ class Plotter:
 
         3. Set tooltips with the solution-values for data-nodes.
         """
-        from .op import Operation
+        from .execution import ExecutionPlan, Solution
 
         theme = plot_args.theme
         graph = plot_args.graph
@@ -1138,9 +1138,9 @@ class Plotter:
                 f"kw_data_io_choice: {io_choice}", theme.kw_data_io_choice[io_choice]
             )
 
-            if is_sideffect(nx_node):
+            if is_sfx(nx_node):
                 styles.add("kw_data_sideffect")
-                if is_sideffected(nx_node):
+                if is_sfxed(nx_node):
                     styles.add("kw_data_sideffected")
 
             ## Data-state
@@ -1169,7 +1169,7 @@ class Plotter:
 
                 elif nx_node in steps:
                     styles.add("kw_data_evicted")
-                elif not is_pruned and not is_sideffect(nx_node):
+                elif not is_pruned and not is_sfx(nx_node):
                     styles.add("kw_data_canceled")
 
             styles.stack_user_style(node_attrs)
