@@ -22,6 +22,7 @@ import pytest
 
 from graphtik import (
     NO_RESULT,
+    NULL_OP,
     AbortedException,
     IncompleteExecutionError,
     abort_run,
@@ -36,9 +37,9 @@ from graphtik import (
     operations_reschedullled,
     tasks_marshalled,
 )
-from graphtik.modifiers import optional, sideffect, sideffected, vararg
-from graphtik.netop import NetworkOperation
-from graphtik.network import Solution
+from graphtik.execution import Solution
+from graphtik.modifiers import optional, sfx, sfxed, vararg
+from graphtik.pipeline import NetworkOperation
 from graphtik.op import Operation
 
 log = logging.getLogger(__name__)
@@ -103,7 +104,7 @@ def filtdict(d, *keys):
     """
     Keep dict items with the given keys
 
-    >>> filtdict({"a": 1, "b": 2}, "b")
+    filtdict({"a": 1, "b": 2}, "b")
     {'b': 2}
     """
     return type(d)(i for i in d.items() if i[0] in keys)
@@ -279,7 +280,25 @@ def test_network_plan_execute():
     assert sol == exp
 
 
-def test_network_simple_merge():
+def test_network_nest_errors(caplog):
+    def screamy_nester(nest_args):
+        raise RuntimeError("Bluff")
+
+    with pytest.raises(RuntimeError, match="Bluff"):
+        compose(
+            "test_nest_err",
+            operation(str, "op1"),
+            operation(str, "op2"),
+            nest=screamy_nester,
+        )
+    for record in caplog.records:
+        if record.levelname == "WARNING":
+            assert "(parent=None, typ='op', op=None, name='op1')" in record.message
+
+
+def test_network_nest_ops_only():
+    def ops_only(nest_args):
+        return nest_args.typ == "op"
 
     sum_op1 = operation(name="sum_op1", needs=["a", "b"], provides="sum1")(add)
     sum_op2 = operation(name="sum_op2", needs=["a", "b"], provides="sum2")(add)
@@ -298,7 +317,7 @@ def test_network_simple_merge():
     sol = net2(**{"d": 1, "e": 2, "f": 4})
     assert sol == exp
 
-    net3 = compose("merged", net1, net2)
+    net3 = compose("merged", net1, net2, nest=ops_only)
     exp = {
         "a": 3,
         "b": 7,
@@ -319,7 +338,7 @@ def test_network_simple_merge():
     )
 
 
-def test_network_deep_merge():
+def test_network_combine():
     sum_op1 = operation(
         name="sum_op1", needs=[vararg("a"), vararg("b")], provides="sum1"
     )(addall)
@@ -331,7 +350,7 @@ def test_network_deep_merge():
     exp = {"a": 1, "b": 2, "c": 4, "sum1": 3, "sum2": 3, "sum3": 7}
     assert net1(a=1, b=2, c=4) == exp
     assert repr(net1).startswith(
-        "NetworkOperation('my network 1', needs=[optional('a'), 'b', 'sum1', 'c'], "
+        "NetworkOperation('my network 1', needs=['a'(?), 'b', 'sum1', 'c'], "
         "provides=['sum1', 'sum2', 'sum3'], x3 ops"
     )
 
@@ -343,48 +362,75 @@ def test_network_deep_merge():
     exp = {"a": 1, "b": 2, "sum1": 3, "sum2": 5}
     assert net2(**{"a": 1, "b": 2}) == exp
     assert repr(net2).startswith(
-        "NetworkOperation('my network 2', needs=[optional('a'), 'b', 'sum1'], provides=['sum1', 'sum2'], x2 ops"
+        "NetworkOperation('my network 2', needs=['a'(?), 'b', 'sum1'], provides=['sum1', 'sum2'], x2 ops"
     )
 
-    net3 = compose("merged", net1, net2, merge=True)
+    net3 = compose("merged", net1, net2)
     exp = {"a": 1, "b": 2, "c": 4, "sum1": 3, "sum2": 5, "sum3": 7}
     assert net3(a=1, b=2, c=4) == exp
 
     assert repr(net3).startswith(
-        "NetworkOperation('merged', needs=[optional('a'), 'b', 'sum1', 'c'], provides=['sum1', 'sum2', 'sum3'], x4 ops"
+        "NetworkOperation('merged', needs=['a'(?), 'b', 'sum1', 'c'], provides=['sum1', 'sum2', 'sum3'], x4 ops"
     )
 
     ## Reverse ops, change results and `needs` optionality.
     #
-    net3 = compose("merged", net2, net1, merge=True)
+    net3 = compose("merged", net2, net1)
     exp = {"a": 1, "b": 2, "c": 4, "sum1": 3, "sum2": 3, "sum3": 7}
     assert net3(**{"a": 1, "b": 2, "c": 4}) == exp
 
     assert repr(net3).startswith(
-        "NetworkOperation('merged', needs=[optional('a'), 'b', 'sum1', 'c'], provides=['sum1', 'sum2', 'sum3'], x4 ops"
+        "NetworkOperation('merged', needs=['a'(?), 'b', 'sum1', 'c'], provides=['sum1', 'sum2', 'sum3'], x4 ops"
     )
 
 
-def test_network_merge_in_doctests(merge_pipes):
-    graphop, another_graph = merge_pipes
-    merged_graph = compose("merged_graph", graphop, another_graph, merge=False)
+def test_network_merge_in_doctests():
+    days_count = 3
 
-    print(merged_graph)
-    assert str(merged_graph).startswith(
-        "NetworkOperation('merged_graph', "
-        "needs=['a', 'b', 'ab', 'a_minus_ab', 'c'], "
-        "provides=['ab', 'a_minus_ab', 'abs_a_minus_ab_cubed', 'cab'], x5 ops: "
-        "graphop.mul1, graphop.sub1, graphop.abspow1, another_graph.mul1, another_graph.mul2)"
+    weekday = compose(
+        "weekday",
+        operation(str, name="wake up", needs="backlog", provides="tasks"),
+        operation(str, name="sleep", needs="tasks", provides="todos"),
     )
 
-    merged_graph = compose("merged_graph", graphop, another_graph, merge=True)
-    print(merged_graph)
-    assert str(merged_graph).startswith(
-        "NetworkOperation('merged_graph', "
-        "needs=['a', 'b', 'ab', 'a_minus_ab', 'c'], "
-        "provides=['ab', 'a_minus_ab', 'abs_a_minus_ab_cubed', 'cab'], x4 ops: "
-        "mul1, sub1, abspow1, mul2)"
+    weekday = compose(
+        "weekday",
+        operation(
+            lambda t: (t[:-1], t[-1:]),
+            name="work!",
+            needs="tasks",
+            provides=["tasks done", "todos"],
+        ),
+        operation(str, name="sleep"),
+        weekday,
     )
+    assert len(weekday.ops) == 3
+
+    weekday = compose("weekday", NULL_OP("sleep"), weekday)
+    assert len(weekday.ops) == 2
+
+    weekdays = [weekday.withset(name=f"day {i}") for i in range(days_count)]
+    week = compose("week", *weekdays, nest=True)
+    assert len(week.ops) == 6
+
+    def nester(nest_args):
+        if nest_args.name not in ("backlog", "tasks done", "todos"):
+            return True
+
+    week = compose("week", *weekdays, nest=nester)
+    assert len(week.ops) == 6
+    sol = week.compute({"backlog": "a lot!"})
+    assert sol == {
+        "backlog": "a lot!",
+        "day 0.tasks": "a lot!",
+        "tasks done": "a lot",
+        "todos": "!",
+        "day 1.tasks": "a lot!",
+        "day 2.tasks": "a lot!",
+    }
+
+    dot = sol.plot()
+    assert len(dot.get_subgraphs()) == days_count
 
 
 def test_aliases(exemethod):
@@ -617,7 +663,7 @@ def test_pruning_multiouts_not_override_intermediates2(exemethod):
     solution = pipeline.compute(inputs, "asked")
     assert solution == filtdict(exp, "asked")
     assert solution.overwrites == {}
-    # ... but overrites collected if asked.
+    # ... but overwrites collected if asked.
     #
     solution = pipeline.compute(inputs, ["asked", "overridden"])
     assert solution == filtdict(exp, "asked", "overridden")
@@ -796,7 +842,9 @@ def test_narrow_and_optionality(reverse):
     if reverse:
         ops = list(reversed(ops))
         provides = "'sum2', 'sum1'"
-    netop_str = f"NetworkOperation('t', needs=['a', optional('bb')], provides=[{provides}], x2 ops"
+    netop_str = (
+        f"NetworkOperation('t', needs=['a', 'bb'(?)], provides=[{provides}], x2 ops"
+    )
 
     netop = compose("t", *ops)
     assert repr(netop).startswith(netop_str)
@@ -814,7 +862,7 @@ def test_narrow_and_optionality(reverse):
     netop = compose("t", *ops)
     assert repr(netop).startswith(netop_str)
     assert repr(netop.compile(["bb"])).startswith(
-        "ExecutionPlan(needs=[optional('bb')], provides=['sum1'], x1 steps:"
+        "ExecutionPlan(needs=['bb'(?)], provides=['sum1'], x1 steps:"
     )
 
     ## Narrow by `provides`
@@ -822,7 +870,7 @@ def test_narrow_and_optionality(reverse):
     netop = compose("t", *ops, outputs="sum1")
     assert repr(netop).startswith(netop_str)
     assert repr(netop.compile("bb")).startswith(
-        "ExecutionPlan(needs=[optional('bb')], provides=['sum1'], x3 steps:"
+        "ExecutionPlan(needs=['bb'(?)], provides=['sum1'], x3 steps:"
     )
     assert repr(netop.compile("bb")) == repr(netop.compute({"bb": 1}).plan)
 
@@ -838,7 +886,7 @@ def test_narrow_and_optionality(reverse):
     #
     netop = compose("t", *ops, outputs=["sum1"])
     assert repr(netop.compile(inputs="a")).startswith(
-        "ExecutionPlan(needs=[optional('a')], provides=['sum1'], x3 steps:"
+        "ExecutionPlan(needs=['a'(?)], provides=['sum1'], x3 steps:"
     )
 
     netop = compose("t", *ops, outputs=["sum2"])
@@ -859,12 +907,12 @@ def _box_increment(box):
 @pytest.fixture(params=[0, 1])
 def netop_sideffect1(request, exemethod) -> NetworkOperation:
     ops = [
-        operation(
-            name="extend", needs=["box", sideffect("a")], provides=[sideffect("b")]
-        )(_box_extend),
-        operation(
-            name="increment", needs=["box", sideffect("b")], provides=sideffect("c")
-        )(_box_increment),
+        operation(name="extend", needs=["box", sfx("a")], provides=[sfx("b")])(
+            _box_extend
+        ),
+        operation(name="increment", needs=["box", sfx("b")], provides=sfx("c"))(
+            _box_increment
+        ),
     ]
     if request.param:
         ops = reversed(ops)
@@ -897,7 +945,7 @@ def test_sideffect_no_real_data(netop_sideffect1: NetworkOperation):
         assert graph.compute(inp)
 
     with pytest.raises(ValueError, match="Unsolvable graph"):
-        graph.compute(inp, ["box", sideffect("b")])
+        graph.compute(inp, ["box", sfx("b")])
 
     with pytest.raises(ValueError, match="Unsolvable graph"):
         # Cannot run, since no sideffect inputs given.
@@ -908,19 +956,19 @@ def test_sideffect_no_real_data(netop_sideffect1: NetworkOperation):
     ## OK INPUT SIDEFFECTS
     #
     # ok, no asked out
-    sol = graph.compute({"box": [0], sideffect("a"): True})
-    assert sol == {"box": box_orig if sidefx_fail else [1, 2, 3], sideffect("a"): True}
+    sol = graph.compute({"box": [0], sfx("a"): True})
+    assert sol == {"box": box_orig if sidefx_fail else [1, 2, 3], sfx("a"): True}
     #
     # bad, not asked the out-sideffect
     with pytest.raises(ValueError, match="Unsolvable graph"):
-        graph.compute({"box": [0], sideffect("a"): True}, "box")
+        graph.compute({"box": [0], sfx("a"): True}, "box")
     #
     # ok, asked the 1st out-sideffect
-    sol = graph.compute({"box": [0], sideffect("a"): True}, ["box", sideffect("b")])
+    sol = graph.compute({"box": [0], sfx("a"): True}, ["box", sfx("b")])
     assert sol == {"box": box_orig if sidefx_fail else [0, 1, 2]}
     #
     # ok, asked the 2nd out-sideffect
-    sol = graph.compute({"box": [0], sideffect("a"): True}, ["box", sideffect("c")])
+    sol = graph.compute({"box": [0], sfx("a"): True}, ["box", sfx("c")])
     assert sol == {"box": box_orig if sidefx_fail else [1, 2, 3]}
 
 
@@ -931,10 +979,8 @@ def test_sideffect_real_input(reverse, exemethod):
     )
 
     ops = [
-        operation(name="extend", needs=["box", "a"], provides=[sideffect("b")])(
-            _box_extend
-        ),
-        operation(name="increment", needs=["box", sideffect("b")], provides="c")(
+        operation(name="extend", needs=["box", "a"], provides=[sfx("b")])(_box_extend),
+        operation(name="increment", needs=["box", sfx("b")], provides="c")(
             _box_increment
         ),
     ]
@@ -962,7 +1008,7 @@ def test_sideffect_steps(exemethod, netop_sideffect1: NetworkOperation):
 
     netop = netop_sideffect1.withset(parallel=exemethod)
     box_orig = [0]
-    sol = netop.compute({"box": [0], sideffect("a"): True}, ["box", sideffect("c")])
+    sol = netop.compute({"box": [0], sfx("a"): True}, ["box", sfx("c")])
     assert sol == {"box": box_orig if sidefx_fail else [1, 2, 3]}
     assert len(netop.last_plan.steps) == 4
 
@@ -975,11 +1021,11 @@ def test_sideffect_steps(exemethod, netop_sideffect1: NetworkOperation):
 def test_sideffect_NO_RESULT(caplog, exemethod):
     # NO_RESULT does not cancel sideffects unless op-rescheduled
     #
-    sfx = sideffect("b")
-    op1 = operation(lambda: NO_RESULT, name="do-SFX", provides=sfx)
-    op2 = operation(lambda: 1, name="ask-SFX", needs=sfx, provides="a")
+    an_sfx = sfx("b")
+    op1 = operation(lambda: NO_RESULT, name="do-SFX", provides=an_sfx)
+    op2 = operation(lambda: 1, name="ask-SFX", needs=an_sfx, provides="a")
     netop = compose("t", op1, op2, parallel=exemethod)
-    sol = netop.compute({}, outputs=sfx)
+    sol = netop.compute({}, outputs=an_sfx)
     assert op1 in sol.executed
     assert op2 not in sol.executed
     assert sol == {}
@@ -998,88 +1044,95 @@ def test_sideffect_NO_RESULT(caplog, exemethod):
     sol = netop.compute({})
     assert op1 in sol.executed
     assert op2 not in sol.executed
-    assert sol == {sfx: False}
+    assert sol == {an_sfx: False}
     sol = netop.compute({}, outputs="a")
     assert op2 not in sol.executed
     assert op1 in sol.executed
-    assert sol == {}  # sfx evicted
+    assert sol == {}  # an_sfx evicted
 
     ## If NO_RESULT were not translated,
     #  a warning of unknown out might have emerged.
     caplog.clear()
-    netop = compose("t", operation(lambda: 1, provides=sfx), parallel=exemethod)
-    netop.compute({}, outputs=sfx)
+    netop = compose("t", operation(lambda: 1, provides=an_sfx), parallel=exemethod)
+    netop.compute({}, outputs=an_sfx)
     for record in caplog.records:
         if record.levelname == "WARNING":
             assert "Ignoring result(1) because no `provides`" in record.message
 
     caplog.clear()
-    netop = compose("t", operation(lambda: NO_RESULT, provides=sfx), parallel=exemethod)
-    netop.compute({}, outputs=sfx)
+    netop = compose(
+        "t", operation(lambda: NO_RESULT, provides=an_sfx), parallel=exemethod
+    )
+    netop.compute({}, outputs=an_sfx)
     for record in caplog.records:
         assert record.levelname != "WARNING"
 
 
 def test_sideffect_cancel_sfx_only_operation(exemethod):
-    sfx = sideffect("b")
+    an_sfx = sfx("b")
     op1 = operation(
-        lambda: {sfx: False},
+        lambda: {an_sfx: False},
         name="op1",
-        provides=sfx,
+        provides=an_sfx,
         returns_dict=True,
         rescheduled=True,
     )
-    op2 = operation(lambda: 1, name="op2", needs=sfx, provides="a")
+    op2 = operation(lambda: 1, name="op2", needs=an_sfx, provides="a")
     netop = compose("t", op1, op2, parallel=exemethod)
     sol = netop.compute({})
-    assert sol == {sfx: False}
-    sol = netop.compute(outputs=sfx)
-    assert sol == {sfx: False}
+    assert sol == {an_sfx: False}
+    sol = netop.compute(outputs=an_sfx)
+    assert sol == {an_sfx: False}
 
 
 def test_sideffect_cancel(exemethod):
-    sfx = sideffect("b")
+    an_sfx = sfx("b")
     op1 = operation(
-        lambda: {"a": 1, sfx: False},
+        lambda: {"a": 1, an_sfx: False},
         name="op1",
-        provides=["a", sfx],
+        provides=["a", an_sfx],
         returns_dict=True,
         rescheduled=True,
     )
-    op2 = operation(lambda: 1, name="op2", needs=sfx, provides="b")
+    op2 = operation(lambda: 1, name="op2", needs=an_sfx, provides="b")
     netop = compose("t", op1, op2, parallel=exemethod)
     sol = netop.compute()
-    assert sol == {"a": 1, sfx: False}
+    assert sol == {"a": 1, an_sfx: False}
     sol = netop.compute(outputs="a")
-    assert sol == {"a": 1}  # sfx evicted
+    assert sol == {"a": 1}  # an_sfx evicted
     ## SFX both pruned & evicted
     #
-    assert sfx not in sol.dag.nodes
-    assert sfx in sol.plan.steps
+    assert an_sfx not in sol.dag.nodes
+    assert an_sfx in sol.plan.steps
 
 
 def test_sideffect_not_canceled_if_not_resched(exemethod):
     # Check op without any provides
     #
-    sfx = sideffect("b")
-    op1 = operation(lambda: {sfx: False}, name="op1", provides=sfx, returns_dict=True)
-    op2 = operation(lambda: 1, name="op2", needs=sfx, provides="b")
+    an_sfx = sfx("b")
+    op1 = operation(
+        lambda: {an_sfx: False}, name="op1", provides=an_sfx, returns_dict=True
+    )
+    op2 = operation(lambda: 1, name="op2", needs=an_sfx, provides="b")
     netop = compose("t", op1, op2, parallel=exemethod)
     # sol = netop.compute()
-    # assert sol == {sfx: False, "b": 1}
+    # assert sol == {an_sfx: False, "b": 1}
     sol = netop.compute(outputs="b")
     assert sol == {"b": 1}
 
     # Check also op with some provides
     #
-    sfx = sideffect("b")
+    an_sfx = sfx("b")
     op1 = operation(
-        lambda: {"a": 1, sfx: False}, name="op1", provides=["a", sfx], returns_dict=True
+        lambda: {"a": 1, an_sfx: False},
+        name="op1",
+        provides=["a", an_sfx],
+        returns_dict=True,
     )
-    op2 = operation(lambda: 1, name="op2", needs=sfx, provides="b")
+    op2 = operation(lambda: 1, name="op2", needs=an_sfx, provides="b")
     netop = compose("t", op1, op2, parallel=exemethod)
     sol = netop.compute()
-    assert sol == {"a": 1, sfx: False, "b": 1}
+    assert sol == {"a": 1, an_sfx: False, "b": 1}
     sol = netop.compute(outputs="b")
     assert sol == {"b": 1}
 
@@ -1088,7 +1141,7 @@ def test_sideffect_not_canceled_if_not_resched(exemethod):
 def calc_prices_pipeline(request, exemethod):
     """A pipeline that may work even without VAT-rates."""
 
-    @operation(needs="order_items", provides=sideffected("ORDER", "Items", "Prices"))
+    @operation(needs="order_items", provides=sfxed("ORDER", "Items", "Prices"))
     def new_order(items: list) -> "pd.DataFrame":
         order = {"items": items}
         # Pretend we get the prices from sales.
@@ -1096,8 +1149,8 @@ def calc_prices_pipeline(request, exemethod):
         return order
 
     @operation(
-        needs=[sideffected("ORDER", "Items"), "vat rate"],
-        provides=sideffected("ORDER", "VAT rates"),
+        needs=[sfxed("ORDER", "Items"), "vat rate"],
+        provides=sfxed("ORDER", "VAT rates"),
     )
     def fill_in_vat_ratios(order: "pd.DataFrame", base_vat: float) -> "pd.DataFrame":
         order["VAT_rates"] = [
@@ -1106,11 +1159,8 @@ def calc_prices_pipeline(request, exemethod):
         return order
 
     @operation(
-        needs=[
-            sideffected("ORDER", "Prices"),
-            sideffected("ORDER", "VAT rates", optional=True),
-        ],
-        provides=[sideffected("ORDER", "VAT", "Totals"), "vat owed"],
+        needs=[sfxed("ORDER", "Prices"), sfxed("ORDER", "VAT rates", optional=True),],
+        provides=[sfxed("ORDER", "VAT", "Totals"), "vat owed"],
     )
     def finalize_prices(order: "pd.DataFrame") -> Tuple["pd.DataFrame", float]:
         if "VAT_rates" in order:
@@ -1145,7 +1195,7 @@ def test_sideffecteds_ok(calc_prices_pipeline):
         "vat owed": 1.44,
     }
     sol = calc_prices_pipeline.compute(
-        inp, [sideffected("ORDER", "VAT"), sideffected("ORDER", "Totals")]
+        inp, [sfxed("ORDER", "VAT"), sfxed("ORDER", "Totals")]
     )
     print(sol)
     assert sol == {
@@ -1175,15 +1225,15 @@ def test_sideffecteds_endured(calc_prices_pipeline):
     ## Break `fill_in_vat_ratios()`.
     #
     @operation(
-        needs=[sideffected("ORDER", "Items"), "vat rate"],
-        provides=sideffected("ORDER", "VAT rates"),
+        needs=[sfxed("ORDER", "Items"), "vat rate"],
+        provides=sfxed("ORDER", "VAT rates"),
         endured=True,
     )
     def fill_in_vat_ratios(order: "pd.DataFrame", base_vat: float) -> "pd.DataFrame":
         raise ValueError("EC transactions have no VAT!")
 
     calc_prices_pipeline = compose(
-        calc_prices_pipeline.name, fill_in_vat_ratios, calc_prices_pipeline, merge=True
+        calc_prices_pipeline.name, fill_in_vat_ratios, calc_prices_pipeline, nest=False
     )
 
     sol = calc_prices_pipeline.compute(
@@ -1205,15 +1255,15 @@ def test_sideffecteds_endured(calc_prices_pipeline):
 
 @pytest.fixture(params=[0, 1])
 def sideffected_resched(request, exemethod):
-    @operation(provides=sideffected("DEP", "yes", "no"), rescheduled=1, returns_dict=1)
+    @operation(provides=sfxed("DEP", "yes", "no"), rescheduled=1, returns_dict=1)
     def half_sfx():
-        return {"DEP": 1, sideffected("DEP", "no"): False}
+        return {"DEP": 1, sfxed("DEP", "no"): False}
 
     yes = operation(
-        lambda dep: "yes!", name="YES", needs=sideffected("DEP", "yes"), provides="yes",
+        lambda dep: "yes!", name="YES", needs=sfxed("DEP", "yes"), provides="yes",
     )
     no = operation(
-        lambda dep: "no!", name="NO", needs=sideffected("DEP", "no"), provides="no",
+        lambda dep: "no!", name="NO", needs=sfxed("DEP", "no"), provides="no",
     )
     ops = [half_sfx, yes, no]
     if request.param:
@@ -1225,7 +1275,7 @@ def test_sideffected_canceled(sideffected_resched):
     """Check if a `returns-dict` op can cancel sideffecteds. """
     sol = sideffected_resched.compute({})
     print(sol)
-    assert sol == {"DEP": 1, sideffected("DEP", "no"): False, "yes": "yes!"}
+    assert sol == {"DEP": 1, sfxed("DEP", "no"): False, "yes": "yes!"}
 
 
 def test_optional_per_function_with_same_output(exemethod):
@@ -1500,7 +1550,7 @@ def test_parallel_execution(exemethod):
         operation(name="e", needs=["ao", "bo"], provides="eo")(fn2),
         operation(name="f", needs="eo", provides="fo")(fn),
         operation(name="g", needs="fo", provides="go")(fn),
-        merge=True,
+        nest=False,
     )
 
     t0 = time.time()
@@ -1542,7 +1592,7 @@ def test_multi_threading_computes():
         operation(name="op_a", needs=["a", "b"], provides="c")(op_a),
         operation(name="op_b", needs=["c", "b"], provides="d")(op_b),
         operation(name="op_c", needs=["a", "b"], provides="e")(op_c),
-        merge=True,
+        nest=False,
     )
 
     def infer(i):
@@ -1562,7 +1612,7 @@ def test_multi_threading_computes():
 
 
 @pytest.mark.parametrize("bools", range(4))
-def test_compose_another_network(exemethod, bools):
+def test_combine_networks(exemethod, bools):
     # Code from `compose.rst` examples
     if not exemethod:
         return
@@ -1589,6 +1639,7 @@ def test_compose_another_network(exemethod, bools):
             name="sub2", needs=["a_minus_ab", "c"], provides="a_minus_ab_minus_c"
         )(sub),
         parallel=parallel2,
+        nest=lambda nest_args: nest_args.typ == "op",
     )
     ## Ensure all old-nodes were prefixed.
     #
