@@ -10,7 +10,7 @@ from types import SimpleNamespace
 import dill
 import pytest
 
-from graphtik import NO_RESULT, compose, operation, optional, sideffect, vararg, varargs
+from graphtik import NO_RESULT, compose, operation, optional, sfx, vararg, varargs
 from graphtik.config import (
     operations_endured,
     operations_reschedullled,
@@ -26,17 +26,17 @@ from graphtik.op import (
 )
 
 
-@pytest.fixture(params=[None, ["some"]])
+@pytest.fixture(params=[None, "got"])
 def opname(request):
     return request.param
 
 
-@pytest.fixture(params=[None, ["some"]])
+@pytest.fixture(params=[None, "some"])
 def opneeds(request):
     return request.param
 
 
-@pytest.fixture(params=[None, ["some"]])
+@pytest.fixture(params=[None, "stuff"])
 def opprovides(request):
     return request.param
 
@@ -150,10 +150,6 @@ def test_func_op_validation(opargs, exp):
             {"node_props": "ab"},
             TypeError("node_props` must be a dict, was 'str':"),
         ),
-        ((), {"parents": []}, None),
-        ((), {"parents": ["gg"]}, TypeError("parents` must be tuple, was 'list':")),
-        ((), {"parents": 3.14}, TypeError("parents` must be tuple, was 'float':")),
-        ((), {"parents": "gg"}, TypeError("parents` must be tuple, was 'str':")),
     ],
 )
 def test_func_op_init(args, kw, exp):
@@ -310,7 +306,7 @@ def test_netop_merge_node_props():
     op3 = operation(lambda: None, name="b", node_props={"a": 3, "c": 4})
     netop2 = compose("n2", op2, op3)
 
-    netop = compose("n", netop1, netop2, node_props={"bb": 22, "c": 44}, merge=False)
+    netop = compose("n", netop1, netop2, node_props={"bb": 22, "c": 44}, nest=True)
     exp = {
         "n1.a": {"a": 1, "bb": 22, "c": 44},
         "n2.a": {"a": 11, "b": 0, "bb": 22, "c": 44},
@@ -319,7 +315,7 @@ def test_netop_merge_node_props():
     node_props = _collect_op_props(netop)
     assert node_props == exp
 
-    netop = compose("n", netop1, netop2, node_props={"bb": 22, "c": 44}, merge=True)
+    netop = compose("n", netop1, netop2, node_props={"bb": 22, "c": 44}, nest=False)
     exp = {"a": {"a": 1, "bb": 22, "c": 44}, "b": {"a": 3, "bb": 22, "c": 44}}
     node_props = _collect_op_props(netop)
     assert node_props == exp
@@ -352,13 +348,11 @@ def test_as_renames(inp, exp):
             r"The `aliases` for ['a', 'b'] rename ['b'], not found in provides ['a']!",
         ),
         (
-            lambda: dict(
-                name="t", provides=sideffect("a"), aliases={sideffect("a"): 1}
-            ),
+            lambda: dict(name="t", provides=sfx("a"), aliases={sfx("a"): 1}),
             "must not contain `sideffects",
         ),
         (
-            lambda: dict(name="t", provides="a", aliases={"a": sideffect("AA")}),
+            lambda: dict(name="t", provides="a", aliases={"a": sfx("AA")}),
             "must not contain `sideffects",
         ),
     ],
